@@ -6,7 +6,8 @@ from django.db.models import Q
 
 from queryable_properties.exceptions import QueryablePropertyError
 from queryable_properties.properties import (AnnotationGetterMixin, AnnotationMixin, boolean_filter, LookupFilterMixin,
-                                             lookup_filter, QueryableProperty)
+                                             lookup_filter, QueryableProperty, REMAINING_LOOKUPS)
+from queryable_properties.utils import get_queryable_property
 
 from ..app_management.models import ApplicationWithClassBasedProperties
 
@@ -38,6 +39,22 @@ class DerivedLookupFilterProperty(BaseLookupFilterProperty):
         return Q(dummy__in=value)
 
 
+class ParentRemainingLookupFilterProperty(LookupFilterMixin, AnnotationMixin, QueryableProperty):
+
+    remaining_lookups_via_parent = True
+
+    @lookup_filter('exact')
+    def filter_equality(self, cls, lookup, value):
+        return Q(exact=value)
+
+
+class MethodRemainingLookupFilterProperty(ParentRemainingLookupFilterProperty):
+
+    @lookup_filter(REMAINING_LOOKUPS)
+    def filter_remaining(self, cls, lookup, value):
+        return Q(remaining=value)
+
+
 class TestLookupFilterMixin(object):
 
     def test_registration(self):
@@ -81,6 +98,22 @@ class TestLookupFilterMixin(object):
         assert q.children[0] == expected_q_value
         assert q.negated is expected_q_negation
 
+    @pytest.mark.parametrize('cls, lookup, value, expected_q_value', [
+        (ParentRemainingLookupFilterProperty, 'exact', 1337, ('exact', 1337)),
+        (ParentRemainingLookupFilterProperty, 'gt', 42, ('dummy__gt', 42)),
+        (ParentRemainingLookupFilterProperty, 'lte', 69, ('dummy__lte', 69)),
+        (MethodRemainingLookupFilterProperty, 'exact', 1337, ('exact', 1337)),
+        (MethodRemainingLookupFilterProperty, 'gt', 42, ('remaining', 42)),
+        (MethodRemainingLookupFilterProperty, 'lte', 69, ('remaining', 69)),
+    ])
+    def test_remaining_lookups(self, cls, lookup, value, expected_q_value):
+        prop = cls()
+        prop.model = ApplicationWithClassBasedProperties
+        prop.name = 'dummy'
+        q = prop.get_filter(None, lookup, value)
+        assert len(q.children) == 1
+        assert q.children[0] == expected_q_value
+
     @pytest.mark.parametrize('cls, lookup, value', [
         (BaseLookupFilterProperty, 'month', 5),
         (BaseLookupFilterProperty, 'gt', 42),
@@ -125,13 +158,15 @@ class TestAnnotationGetterMixin(object):
 
     @pytest.fixture
     def prop(self):
-        assert isinstance(ApplicationWithClassBasedProperties.version_count, AnnotationGetterMixin)
-        return ApplicationWithClassBasedProperties.version_count
+        prop = get_queryable_property(ApplicationWithClassBasedProperties, 'version_count')
+        assert isinstance(prop, AnnotationGetterMixin)
+        return prop
 
     @pytest.fixture
     def nested_prop(self):
-        assert isinstance(ApplicationWithClassBasedProperties.major_avg, AnnotationGetterMixin)
-        return ApplicationWithClassBasedProperties.major_avg
+        prop = get_queryable_property(ApplicationWithClassBasedProperties, 'major_avg')
+        assert isinstance(prop, AnnotationGetterMixin)
+        return prop
 
     @pytest.mark.parametrize('kwargs, expected_cached', [
         ({}, QueryableProperty.cached),
